@@ -8,7 +8,8 @@ from pyspark.sql.utils import AnalysisException
 
 from getl.block import BlockConfig
 from getl.common.errors import NoDataToProcess
-from getl.common.utils import fetch_s3_file, json_to_spark_schema
+from getl.common.s3path import S3Path
+from getl.common.utils import json_to_spark_schema
 
 
 def resolve(func, conf: BlockConfig) -> DataFrame:
@@ -22,19 +23,46 @@ def resolve(func, conf: BlockConfig) -> DataFrame:
     return dataframe
 
 
+def batch_csv(conf: BlockConfig) -> DataFrame:
+    """Load csv data in batch.
+
+    :param str Path: path to the csv files
+    :param dict Options: [options](https://spark.apache.org/docs/latest/api/python/pyspark.sql.html#pyspark.sql.DataFrameReader.csv) to be passed to the csv reader
+    :param str Alias=: an alias for the dataframe that is loaded
+
+    ```
+    SectionName:
+        Type: load::batch_csv
+        Properties:
+            Path: s3://bucket-name/trusted/live
+            Options:
+                header: True
+                inferSchema: True
+            Alias: settings
+    ```
+
+    """
+    return _batch_read(
+        conf.spark,
+        _process_path(conf, suffix=".csv"),
+        file_format="csv",
+        options=conf.get("Options", {}),
+    )
+
+
 def batch_parquet(conf: BlockConfig) -> DataFrame:
     """Load parquet data in batch.
 
     :param str Path: path to the data files
-    :param str FileRegistry: optional, name of the fileregistry to use
-    :param str Alias: alias of some sort?
+    :param str FileRegistry=: name of the fileregistry to use
+    :param str Alias=: an alias for the dataframe that is loaded
 
     ```
     SectionName:
         Type: load::batch_parquet
         Properties:
-            Path: s3://husvarna-datalake/trusted/amc/live
-            FileRegistry: PrefixBasedDate
+            Path: s3://bucket-name/trusted/live
+            FileRegistry: S3DatePrefixScan
             Alias: settings
     ```
 
@@ -48,52 +76,57 @@ def batch_json(conf: BlockConfig) -> DataFrame:
     """Load json data in batch.
 
     :param str Path: path to the data files
-    :param str FileRegistry: optional, name of the fileregistry to use
-    :param str Alias: alias of some sort?
-    :param str Suffix: the suffix of the file, default .json
+    :param str FileRegistry=: name of the fileregistry to use
+    :param str Alias=: an alias for the dataframe that is loaded
+    :param str Suffix=.json: the suffix of the file
+    :param str JsonSchemaPath=: the file schema in json format
 
 
     ```
     SectionName:
         Type: load::batch_json
         Properties:
-            Path: s3://husvarna-datalake/trusted/amc/live
-            FileRegistry: PrefixBasedDate
+            Path: s3://bucket-name/trusted/live
+            FileRegistry: S3DatePrefixScan
             Alias: settings
             Suffix: .json
+            JsonSchemaPath: s3://bucket-name/schema.json
     ```
 
     """
     paths = _process_path(conf, suffix=conf.get("Suffix", ".json"))
-    schema = json.loads(fetch_s3_file(conf.get("JsonSchemaPath")))
+    schema_path = conf.get("JsonSchemaPath", None)
+    if schema_path:
+        schema = json.loads(S3Path(schema_path).read_text())
+        options = {"schema": json_to_spark_schema(schema)}
+    else:
+        options = {"inferSchema": "true"}
 
-    return _batch_read(
-        conf.spark,
-        paths,
-        file_format="json",
-        options={"schema": json_to_spark_schema(schema)},
-    )
+    return _batch_read(conf.spark, paths, file_format="json", options=options)
 
 
 def batch_xml(conf: BlockConfig) -> DataFrame:
     """Load xml data in batch.
 
     :param str Path: path to the data files
-    :param str FileRegistry: optional, name of the fileregistry to use
-    :param str Alias: alias of some sort?
-    :param str Suffix: the suffix of the file, default .xml
-    :param int BatchSize: the amount of data to process in 1 go
+    :param str RowTag: the row tag that indicates a new item in the xml structure
+    :param str FileRegistry=: name of the fileregistry to use
+    :param str Alias=: an alias for the dataframe that is loaded
+    :param str Suffix=.xml: the suffix of the file
+    :param int BatchSize=200: the amount of data to process in one go
+    :param str JsonSchemaPath=: the file schema in json format
 
     ```
     SectionName:
         Type: load::batch_xml
         Properties:
-            Path: s3://husvarna-datalake/trusted/amc/live
-            FileRegistry: PrefixBasedDate
+            Path: s3://bucket-name/trusted/live
+            FileRegistry: S3DatePrefixScan
             Alias: settings
             RowTag: employee
-            Suffix: .xml # Default .xml
-            BatchSize: 200 # Default 200
+            Suffix: .xml
+            BatchSize: 200
+            JsonSchemaPath: s3://bucket-name/schema.json
     ```
 
     """
@@ -103,46 +136,45 @@ def batch_xml(conf: BlockConfig) -> DataFrame:
         for i in range(0, len(file_paths), batch_size):
             yield file_paths[i : i + batch_size]
 
-    def xml_batch_read(path: str, schema: dict) -> DataFrame:
-        return _batch_read(
-            conf.spark,
-            path,
-            file_format="xml",
-            options={
-                "rowTag": conf.get("RowTag"),
-                "schema": json_to_spark_schema(schema),
-            },
-        )
+    def xml_batch_read(path: str, options: dict) -> DataFrame:
+        return _batch_read(conf.spark, path, file_format="xml", options=options,)
 
-    # Get the paths to process and the schema
+    # Get the paths to process
     path = _process_path(conf, suffix=conf.get("Suffix", ".xml"))
-    schema = json.loads(fetch_s3_file(conf.get("JsonSchemaPath")))
     batch_size = conf.get("BatchSize", 200)
 
+    options = {"rowTag": conf.get("RowTag")}
+    # Get the file schema
+    schema_path = conf.get("JsonSchemaPath", None)
+    if schema_path:
+        schema = json.loads(S3Path(schema_path).read_text())
+        options["schema"] = json_to_spark_schema(schema)
+    else:
+        options["inferSchema"] = "true"
+
     # If we have a list of files transform it into batches of comma seperated strings
-    # The XML modules can only take multiple fiels in the following way file1,file2,file3
+    # The XML modules can only take multiple files in the following way file1,file2,file3
     if isinstance(path, list):
         dfs = [
-            xml_batch_read(",".join(batch), schema)
+            xml_batch_read(",".join(batch), options)
             for batch in get_batches(path, batch_size)
         ]
         return functools.reduce(DataFrame.unionByName, dfs)
 
-    return xml_batch_read(path, schema)
+    return xml_batch_read(path, options)
 
 
 def batch_delta(conf: BlockConfig) -> DataFrame:
     """Load delta data in batch.
 
     :param str Path: path to the data files
-    :param str FileRegistry: optional, name of the fileregistry to use
-    :param str Alias: alias of some sort?
+    :param str Alias=: an alias for the dataframe that is loaded
 
     ```
     SectionName:
         Type: load::batch_delta
         Properties:
-            Path: s3://husvarna-datalake/trusted/amc/live
+            Path: s3://bucket-name/trusted/live
             Alias: settings
     ```
 
@@ -168,8 +200,7 @@ def stream_json(bconf: BlockConfig) -> DataFrame:
 
     :param str Path: path to the data files
     :param str SchemaPath: path to the schema
-    :param str FileRegistry: optional, name of the fileregistry to use
-    :param str Alias: alias of some sort?
+    :param str Alias=: an alias for the dataframe that is loaded
 
     ```
     SectionName:
@@ -181,7 +212,7 @@ def stream_json(bconf: BlockConfig) -> DataFrame:
     ```
 
     """
-    json_schema = json.loads(fetch_s3_file(bconf.props["SchemaPath"]))
+    json_schema = json.loads(S3Path(bconf.props["SchemaPath"]).read_text())
 
     dataframe = bconf.spark.readStream.schema(json_to_spark_schema(json_schema)).json(
         bconf.props["Path"]
@@ -198,8 +229,8 @@ def jdbc(bconf: BlockConfig) -> DataFrame:
     :param str Table: table name with the data
     :param str User: database user
     :param str Password: database password
-    :param str Alias: alias of some sort?
     :param str Query: SQL query to access the data
+    :param str Alias=: an alias for the dataframe that is loaded
 
     ```
     SectionName:
@@ -229,7 +260,9 @@ def jdbc(bconf: BlockConfig) -> DataFrame:
     return dataframe
 
 
-def _batch_read(spark: SparkSession, paths, file_format, options={}):
+def _batch_read(
+    spark: SparkSession, paths: List[str], file_format: str, options: dict = {}
+):
     """Retrives data on batch."""
     return spark.read.load(paths, format=file_format, **options)
 
