@@ -21,23 +21,22 @@ class DeltaTable:
 
     def upsert_all(self, updates_df: DataFrame, merge_statement: str) -> DataFrame:
         """Update and insert all rows and columns."""
-        (
-            self._merge(updates_df, merge_statement)
-            .whenMatchedUpdateAll()
-            .whenNotMatchedInsertAll()
-            .execute()
-        )
-        return self.delta_table.toDF()
+        return self._merge(updates_df, merge_statement, update=True)
 
     def insert_all(self, updates_df: DataFrame, merge_statement: str) -> DataFrame:
         """Insert all new rows that do not match the merge_statement."""
-        (self._merge(updates_df, merge_statement).whenNotMatchedInsertAll().execute())
-        return self.delta_table.toDF()
+        return self._merge(updates_df, merge_statement, update=False)
 
-    def _merge(self, updates_df, merge_statement: str):
-        return self.delta_table.alias("source").merge(
-            updates_df.alias("updates"), merge_statement
+    def _merge(self, updates_df, merge_statement: str, update: bool) -> DataFrame:
+        merged_df = (
+            self.delta_table.alias("source")
+            .merge(updates_df.alias("updates"), merge_statement)
+            .whenNotMatchedInsertAll()
         )
+        if update:
+            merged_df = merged_df.whenMatchedUpdateAll()
+        merged_df.execute()
+        return self.delta_table.toDF()
 
     def _create_delta_table(self) -> "DeltaTable":
         """Create a delta table from a path"""
